@@ -8,6 +8,10 @@ from .booking.order_cancellations import OrderCancellationClient
 from .booking.order_changes import OrderChangeClient
 from .booking.order_change_offers import OrderChangeOfferClient
 from .booking.order_change_requests import OrderChangeRequestClient
+from .booking.partial_offer_requests import (
+    PartialOfferRequestClient,
+    PartialOfferRequestCreate,
+)
 from .booking.payments import PaymentClient
 from .booking.seat_maps import SeatMapClient
 from .duffel_payments.payment_intents import PaymentIntentClient, PaymentIntentCreate
@@ -27,6 +31,8 @@ __all__ = [
     "OrderCreate",
     "OrderUpdate",
     "OrderCancellationClient",
+    "PartialOfferRequestClient",
+    "PartialOfferRequestCreate",
     "PaymentClient",
     "PaymentIntentClient",
     "PaymentIntentCreate",
